# SecureAgentSpec

The specification of the secure agent

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**org_id** | **str** | Unique identifier | 
**name** | **str** | A descriptive name for the secure agent | [optional] 
**application_service_ids** | **[str]** | The list of application service ids associated with this secure agent | [optional] 
**connectors** | [**[SecureAgentConnector]**](SecureAgentConnector.md) | The list of connectors this agent uses to establish tunnels with the infrastructure  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


